@@ -30,22 +30,15 @@ from qctrlcommons.auth import (
     BearerTokenAuth,
     ClientAuthBase,
 )
-from qctrlcommons.exceptions import (
-    QctrlException,
-    QctrlGqlException,
-)
+from qctrlcommons.exceptions import QctrlException
 from qctrlcommons.utils import generate_user_agent
 
 from qctrl.builders.http_transport import QctrlRequestsHTTPTransport
-from qctrl.utils import (
-    TokenError,
-    check_client_version,
-)
+from qctrl.utils import check_client_version
 
 from .. import __version__ as qctrl_version
 from ..queries import (
     CreateTokenQuery,
-    MeQuery,
     RefreshTokenQuery,
 )
 from ..scripts_utils import (
@@ -126,7 +119,7 @@ def _parse_credentials_file(file_path: Union[str, Path]) -> tuple:
         raise OSError(f"credentials file does not exist: {file_path}")
 
     # get data
-    with open(file_path) as json_file:
+    with open(file_path, encoding="utf-8") as json_file:
         data = json_file.read()
         data = json.loads(data)
 
@@ -200,33 +193,6 @@ def create_client_auth(
     return auth
 
 
-def validate_client_auth(authenticated_gql_client: Client) -> None:
-    """
-    Checks that the generated client has a valid authentication.
-
-    Parameters
-    ----------
-    authenticated_gql_client: gql.Client
-        An authenticated GQL client to be used in a test request.
-
-    Raises
-    ------
-    QctrlGqlException
-        If any other issue happens with the request.
-    TokenError
-        If token is invalid or expired.
-    """
-
-    me_query = MeQuery(authenticated_gql_client)
-
-    try:
-        me_query()
-    except QctrlGqlException as error:
-        if "token" in str(error):
-            raise TokenError from error
-        raise
-
-
 @check_client_version
 def create_gql_client(
     api_root: str, auth: ClientAuthBase = None, headers: Dict = None
