@@ -11,6 +11,7 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 # pylint:disable=missing-module-docstring
+import numpy as np
 from graphql import GraphQLList
 
 from .base import BaseHandler
@@ -27,9 +28,9 @@ class ListHandler(BaseHandler, PayloadMixin, SelectionMixin, DataMixin):
     _field_type = GraphQLList
 
     def _format_payload(self, field_type, data):
-        if not isinstance(data, list):
+        if not isinstance(data, (list, tuple, np.ndarray)):
             raise TypeError(
-                f"{data} is of type {type(data)}, but type {list} was expected instead. "
+                f"{data} is of type {type(data)}, but expected a list, tuple, or array instead."
             )
 
         result = []
