@@ -107,11 +107,11 @@ class ActivityMonitorQuery(StaticQuery):
 
         for row in response["actions"]["actions"]:
             name = _snake_core_name(row["name"])
-            created_at = "{:%Y-%m-%d %H:%M:%S}".format(isoparse(row["createdAt"]))
+            created_at = isoparse(row["createdAt"]).strftime("%Y-%m-%d %H:%M:%S")
             completed_at = (
                 ""
                 if row["status"] == "STARTED" or row["status"] == "PENDING"
-                else "{:%Y-%m-%d %H:%M:%S}".format(isoparse(row["updatedAt"]))
+                else isoparse(row["updatedAt"]).strftime("%Y-%m-%d %H:%M:%S")
             )
             runtime = isoparse(row["updatedAt"]) - isoparse(row["createdAt"])
 
